aboutsummaryrefslogtreecommitdiffstats
path: root/testing
diff options
context:
space:
mode:
Diffstat (limited to 'testing')
-rw-r--r--testing/command.py4
-rw-r--r--testing/wheel_tester.py4
2 files changed, 4 insertions, 4 deletions
diff --git a/testing/command.py b/testing/command.py
index 886ab3e74..819fee8ce 100644
--- a/testing/command.py
+++ b/testing/command.py
@@ -160,8 +160,8 @@ def test_project(project, args, blacklist, runs):
def main():
# create the top-level command parser
start_time = timer()
- all_projects = "shiboken2 pyside2 pyside2-tools".split()
- tested_projects = "shiboken2 pyside2".split()
+ all_projects = "shiboken6 pyside2 pyside2-tools".split()
+ tested_projects = "shiboken6 pyside2".split()
parser = argparse.ArgumentParser(
formatter_class=argparse.RawDescriptionHelpFormatter,
description=dedent("""\
diff --git a/testing/wheel_tester.py b/testing/wheel_tester.py
index 100fd18f7..9f4c3ab6c 100644
--- a/testing/wheel_tester.py
+++ b/testing/wheel_tester.py
@@ -111,9 +111,9 @@ def get_examples_dir():
def package_prefix_names():
# Note: shiboken2_generator is not needed for compile_using_pyinstaller,
# but building modules with cmake needs it.
- return ["shiboken2", "shiboken2_generator", "PySide2"]
+ return ["shiboken6", "shiboken6_generator", "PySide2"]
def clean_egg_info():
@@ -111,9 +111,9 @@ def get_examples_dir():
def package_prefix_names():
- # Note: shiboken2_generator is not needed for compile_using_pyinstaller,
+ # Note: shiboken6_generator is not needed for compile_using_pyinstaller,
# but building modules with cmake needs it.